﻿using System.Collections.Specialized;
using System.Linq;
using Infragistics.Windows.Ribbon;
using Microsoft.Practices.Composite.Presentation.Regions;
using Microsoft.Practices.Composite.Regions;

namespace CompositeWPFContrib.Composite.Wpf.Infragistics.DockManager.Regions
{
    public class RibbonTabItemRegionAdapter : RegionAdapterBase<RibbonTabItem>
    {
        public RibbonTabItemRegionAdapter(IRegionBehaviorFactory behaviorFactory)
            : base(behaviorFactory)
        {
        }

        protected override void Adapt(IRegion region, RibbonTabItem ribbonTab)
        {
            if (ribbonTab == null)
                return;

            ribbonTab.RibbonGroups.ToList().ForEach(x => region.Add(x));

            //Implementing the collectionChanged handler
            region.ActiveViews.CollectionChanged += ((x, y) =>
            {
                switch (y.Action)
                {
                    case NotifyCollectionChangedAction.Add:
                        ribbonTab.RibbonGroups.BeginUpdate();
                        foreach (RibbonGroup ribbonGroup in y.NewItems)
                        {
                            ribbonTab.RibbonGroups.Add(ribbonGroup);
                        }
                        ribbonTab.RibbonGroups.EndUpdate();
                        break;

                    case NotifyCollectionChangedAction.Remove:
                        ribbonTab.RibbonGroups.BeginUpdate();
                        foreach (RibbonGroup ribbonGroup in y.NewItems)
                            ribbonTab.RibbonGroups.Remove(ribbonGroup);
                        ribbonTab.RibbonGroups.EndUpdate();
                        break;
                }
            });
        }

        protected override IRegion CreateRegion()
        {
            return new AllActiveRegion();
        }
    }
}